pub enum UnexpandedMacroReason {
RequiresExecution,
Unresolved,
ExpansionUnavailable,
}Expand description
Why an individual macro invocation was not expanded.
Variants
RequiresExecution
Expanding the invocation would execute a procedural macro.
Unresolved
The analysis engine could not resolve the invocation to a macro.
A declarative macro was known but its expansion was unavailable.
Implementations