pub struct CallSite {
pub anchor: Anchor,
pub target: CallTarget,
pub api_name: Option<String>,
}Expand description
One call, and what it was found to call.
Fields
anchor: AnchorWhere the call is.
target: CallTargetWhat it calls.
api_name: Option<String>A compiler-confirmed standard-library API name, when the helper can establish it without deriving it from the stable target identifier.
None for calls outside the deliberately small API vocabulary used by
restricted semantic rules.